-- Threads only load the love.thread module. Others have to be loaded explicitly.
require("love.filesystem")
require("love.timer")
require("love.image")
require("love.graphics")

local rnd = math.random
local qsize = 64

local thisThread = love.thread.getThread()


function populateSpriteBatch(sb, img)
	local iw, ih = img:getWidth(), img:getHeight()
	-- Only using one quad here. You could create many and pass them back of course.
	local quad = love.graphics.newQuad(rnd(0, iw-33), rnd(0, ih-32), qsize, qsize, iw, ih)

	for i = 1, 1000 do
		sb:addq(quad, rnd(100, 700), rnd(100, 500), (rnd()-0.5)*math.pi, 1, 1, qsize/2, qsize/2)
		quad:setViewport(rnd(0, iw-qsize-1), rnd(0, ih-qsize-1), qsize, qsize, iw, ih)

		love.timer.sleep(2) -- Simulating hard work (zzZZzz).

		-- Letting the main thread know how far in we are.
		thisThread:send("progress", i/1000)
	end
end

-- Main thread loop.
while true do
	-- This thread receives commands over the message with the name "cmd".
	local cmd = thisThread:demand("cmd")

	if cmd == "quit" then
		-- "quit" will make the thread terminate by exiting the script.
		return
	elseif cmd == "load" then
		-- "load" gets all the necessary data and passes the result back.
		local sb = thisThread:receive("data")
		local file = thisThread:receive("file")
		local img = love.image.newImageData(file)
		populateSpriteBatch(sb, img)

		thisThread:send("img", img)
		thisThread:send("done", true)
	end
end



