if type(love._version) == "string" then
	error("This is for version 0.7.2!")
end

function love.load()
	loading = true -- Will be false when loadings done and the final SpriteBatch can be displayed.

	-- We need a dummy image for the SpriteBatch. A 16x16 image will load fast and do the trick.
	dummyImageData = love.image.newImageData(16, 16)
	dummyImage = love.graphics.newImage(dummyImageData)

	loadThread = love.thread.newThread("loader", "loader.lua")
	loadThread:start()

	sb = love.graphics.newSpriteBatch(dummyImage, 1000)

	--[[
		This next function is not documented for a reason.
		Any OpenGL calls inbetween lock and unlock can cause crashes,
		data corruption and other horrible things. I'm violating this in
		the script for the example's sake. The bind/unbind functions in 0.8.0
		will be fixed and it should work correctly.

		loack binds the memory of the SpriteBatch to the RAM.
		Updates will not be pushed to the graphics card until we unlock again.
	--]]
	sb:lock()

	-- Sending the data and the command to the thread.
	loadThread:send("data", sb)
	loadThread:send("file", "love.png")
	loadThread:send("cmd", "load")
end

function love.update(dt)
	-- There may be a runtime Lua error in the thread which gets pushed as a message with the name "error".
	if loadThread:peek("error") then
		if loading then
			loadThread:send("cmd", "quit")
			loadThread:wait()

			-- Here's an example why the lock/unlock functions can cause headaches in 0.7.2.
			-- The error message will not be printed to the screen if we don't unlock here.
			sb:unlock()
		end
		error(loadThread:receive("error"))
	end

	if loading then
		-- Wait until the thread is done.
		local isDone = loadThread:receive("done")
		if isDone then
			-- Unlock, create Image and replace the dummy image with it.
			sb:unlock()
			local img = loadThread:receive("img")
			sbImage = love.graphics.newImage(img)
			sb:setImage(sbImage)
			loading = false
		end
	end
end

function love.draw()
	local now = love.timer.getTime()

	if loading then
		local progress = loadThread:peek("progress") or 0
		love.graphics.rectangle("line", 98.5, 498.5, 602, 24)
		love.graphics.rectangle("fill", 100, 500, 600*progress, 20)
	else
		love.graphics.draw(sb, math.cos(now*4.2)*10 + 400, math.sin(now*2.26)*10 + 300, math.sin(now)*0.1, 1, 1, 400, 300)
	end
end

function love.quit()
	-- Very proper cleanup. It's possible to just terminate without waiting for the thread. The OS will take care of it.
	loadThread:send("cmd", "quit")
	loadThread:wait()
end
